@@ -27,6 +27,6 @@ def StyleTransferVideo(list_content_img_path, style_img_path, tfhub_module='http
   return outputs
 
 
-if __name__ == "__main__"
+if __name__ == "__main__":
     import sys
     transfer(sys.argv[1], sys.argv[2])
\ No newline at end of file
